/// <reference types="node" />
/// <reference types="vinyl-fs" />
import urlMod from "url";
import { GetText } from "./get-text";
import { Reporter } from "./reporter";
import { RichProcessCov } from "./spawn-inspected";
interface Watermarks {
    lines: [number, number];
    functions: [number, number];
    branches: [number, number];
    statements: [number, number];
}
export interface FileConfig {
    reporters?: ReadonlyArray<string>;
    globs?: ReadonlyArray<string>;
    coverageDir?: string;
    waterMarks?: Watermarks;
}
export interface CliConfig {
    reporters?: ReadonlyArray<string>;
    globs?: ReadonlyArray<string>;
    coverageDir?: string;
    command: ReadonlyArray<string>;
}
export interface ResolvedConfig {
    reporters: ReadonlyArray<string>;
    globs: ReadonlyArray<string>;
    coverageDir: string;
    waterMarks: Watermarks;
    command: ReadonlyArray<string>;
}
export interface MessageAction {
    action: "message";
    message: string;
    error?: Error;
}
export interface RunAction {
    action: "run";
    config: ResolvedConfig;
}
export declare type CliAction = MessageAction | RunAction;
export declare type ParseArgsResult = MessageAction | {
    action: "run";
    config: CliConfig;
};
/**
 * Executes the c88 CLI
 *
 * @param args CLI arguments
 * @param cwd Current working directory
 * @param proc Current process
 */
export declare function execCli(args: string[], cwd: string, proc: NodeJS.Process): Promise<number>;
export declare function report(reporter: Reporter, processCovs: ReadonlyArray<RichProcessCov>, outStream: NodeJS.WritableStream, outDir: Readonly<urlMod.URL>, getText?: GetText): Promise<void>;
export declare function getAction(args: string[], cwd: string): Promise<CliAction>;
export declare function parseArgs(args: string[]): ParseArgsResult;
export {};
